# Copyright (c) 2000-2001 LOGILAB S.A. (Paris, FRANCE).
# http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
__revision__ = '$Id: Autodoc.py,v 1.5 2001/10/15 09:58:58 syt Exp $'
from narval.lib import *

MOD_XML = '<?xml version="1.0" encoding="ISO-8859-1"?><module name="Autodoc">'

def mk_doc(args, ctrl):
    # read task_ctrl structure
    try:
         group = select_one(args, 'doc-ctrl/group/text()').data
    except:
        group = 'all'
    try:
        lang = select_one(doc_lang, 'doc-ctrl/lang/text()').data
    except:
        lang = 'en'
    try:
        file = select_one(args, 'doc-ctrl/file/text()').data
    except:
        file = 'file:///$NARVAL_HOME/doc/%ss-%s.%s.xml' % (ctrl, group, lang)

    doc = args.ownerDocument
    output = doc.createElementNS('','outputs')
    doc_ctrl = doc.createElementNS('', 'tmp-doc-ctrl')
    txt = doc.createTextNode(lang)
    lang_n = doc.createElementNS('', 'lang')
    doc_ctrl.appendChild(lang_n)
    lang_n.appendChild(txt)
    txt = doc.createTextNode(group)
    group_n = doc.createElementNS('', 'group')
    doc_ctrl.appendChild(group_n)
    group_n.appendChild(txt)
    output.appendChild(doc_ctrl)
    url = doc.createElementNS('', 'url')
    txt = doc.createTextNode(file)
    url.appendChild(txt)
    output.appendChild(url)
    if group != 'all':
        #print 'select %s[@group="%s"]' % (ctrl, group)
        for n in select_many(args, '%s[@group="%s"]' % (ctrl, group)):
            output.appendChild(n)
    else:
        #print 'select all %s' % (ctrl)
        for n in select_many(args, ctrl):
            output.appendChild(n)
    
    return output

COMMONS_IO = """
  <input optional='yes'>
   <match>doc-ctrl</match>
   <description lang='en'>structure for the doc generation process's control,
   optionaly contains childs file, lang, group, which contains a text node
   respectively for: the url where the doc 'll be write (default value: $HOME/doc/{type}s-{group}.{lang}.xml),
   the language abbrev (default value: en),
   the group attributes value for filtering (default value: all, no filtering).
   </description>
  </input>
  <output>  
   <match>tmp-doc-ctrl</match> 
   <description lang='en'>contain the required elements for documentation generation control</description>
  </output> 
  <output>
   <match>url</match>
   <description lang='en'>the file where the documentation will be writen</description>
  </output>
"""

def filter_actions_doc_f(args):
    return mk_doc(args, 'action')
MOD_XML = MOD_XML + '''
<action name="filter_actions_doc" func="filter_actions_doc_f">
  <description lang="en">Select actions and control structure for doc generating</description>
  <input list="yes"><match>action</match></input>
  %s
  <output list='yes'>
   <match>action</match>
   <description lang="en">filtered actions list</description>
  </output>
</action>
''' % COMMONS_IO

def filter_transforms_doc_f(args):
    return mk_doc(args, 'transform')
MOD_XML = MOD_XML + '''
<action name="filter_transforms_doc" func="filter_transforms_doc_f">
  <description lang="en">Select transforms and control structure for doc generating</description>
  <input list="yes"><match>transform</match></input>
  %s
  <output list='yes'>
   <match>transform</match>
   <description lang="en">filtered transforms list</description>
  </output>
</action>
''' % COMMONS_IO

def filter_recipes_doc_f(args):
    return mk_doc(args, 'recipe')
MOD_XML = MOD_XML + '''
<action name="filter_recipes_doc" func="filter_recipes_doc_f">
  <description lang="en">Select recipes and control structure for doc generating</description>
  <input list="yes"><match>recipe</match></input>
  %s
  <output list="yes">
   <match>recipe</match>
   <description lang="en">filtered recipes list</description>
  </output>
</action>
''' % COMMONS_IO

MOD_XML = MOD_XML + "</module>"
